@@ -191,7 +191,7 @@ class NestedPTWorkstationsAssignmentSerializer(WritableNestedSerializer):
 
     class Meta:
         model = PTWorkstations
-        fields = ('id', 'url', 'display', 'name', 'description'
+        fields = ('id', 'slug', 'url', 'display', 'name', 'description'
                   'CN', 'DistinguishedName', 'ad_guid', 'ad_description')
 
 
@@ -205,7 +205,7 @@ class PTWorkstationsAssignmentSerializer(NetBoxModelSerializer):
     class Meta:
         model = PTWorkstationsAssignment
         fields = [
-            'id', 'url', 'display', 'content_type', 'object_id', 'object', 'pt_workstations', 'created', 'last_updated',
+            'id', 'slug', 'url', 'display', 'content_type', 'object_id', 'object', 'pt_workstations', 'created', 'last_updated',
         ]
 
     @swagger_serializer_method(serializer_or_field=serializers.DictField)
